# Generated by Django 2.2.24 on 2022-04-21 09:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('db_email_backend', '0002_auto_20220420_1246'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='email',
            name='has_errors',
        ),
        migrations.AddField(
            model_name='email',
            name='succeeded',
            field=models.BooleanField(default=True, verbose_name='Succeeded?'),
        ),
    ]
