# Generated by Django 2.2.24 on 2022-04-20 09:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('db_email_backend', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='email',
            name='error',
            field=models.TextField(blank=True, verbose_name='Errors'),
        ),
        migrations.AddField(
            model_name='email',
            name='has_errors',
            field=models.BooleanField(default=False, verbose_name='Has Errors'),
        ),
    ]
